from src.recipeparser_kuronai import urlutils
from src.recipeparser_kuronai.recipe import RecipeConverted

def parse_recipe(dom):
    json_metadata = urlutils.get_json_metadata(dom)
    ingredients = get_ingredients(json_metadata)
    steps = get_steps(json_metadata)
    title = get_title(dom)
    new_recipe = RecipeConverted(ingredients, steps, title)
    return new_recipe


def get_ingredients(json_metadata):
    ingredients = json_metadata["recipeIngredient"]
    return ingredients


def get_steps(json_metadata):
    json_txt = json_metadata["recipeInstructions"]
    steps = []

    if type(json_txt) is list:
        json_txt = json_txt[0]

    if "HowToSection" in json_txt.values():
        step_list = json_txt["itemListElement"]
        for step in step_list:
            steps.append(step["text"])

    return steps


def get_title(dom):
    recipe_title = dom.find("meta", property="og:title")["content"]

    if recipe_title is None:
        recipe_title = dom.title.text

    return recipe_title


from src.recipeparser_kuronai import recipeutils, urlutils
from src.recipeparser_kuronai.recipe import RecipeConverted

if __name__ == "__main__":
    #dom = urlutils.convert_to_dom("https://www.foodnetwork.com/recipes/food-network-kitchen/sweet-and-sour-couscous-stuffed-peppers-recipe-2121036")
    dom = urlutils.convert_to_dom("https://www.ricardocuisine.com/en/recipes/9657-barley-stew-with-sausage-meatballs")
    jsond = urlutils.get_json_metadata(dom)
    steps = recipeutils.get_steps(jsond)
    ingredients = recipeutils.get_ingredients(jsond)
    title = recipeutils.get_title(dom)
    new_recipe = RecipeConverted(ingredients, steps, title)
    new_recipe.print_out()


class RecipeConverted:

    def __init__(self, _ingredients, _steps, _title):
        self.ingredients = _ingredients
        self.steps = _steps
        self.title = _title

    def print_out(self):
        print(f"====={self.title}=====")
        print("------Ingredients-------")
        for ingredient in self.ingredients:
            print(f"\t- {ingredient}")
        print("---------------------")

        print("------Steps------")
        step_no = 1
        for step in self.steps:
            print(f"\tStep {step_no}\n\t {step}")
            step_no += 1
        print("-----------------")